==> haskell-implicit-hie-0.1.2.7-208-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-implicit-hie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 implicit-hie
version:              0.1.2.7
visibility:           public
id:                   implicit-hie-0.1.2.7-5p617Ku40Om7Begu7MEW9W
key:                  implicit-hie-0.1.2.7-5p617Ku40Om7Begu7MEW9W
license:              BSD-3-Clause
copyright:            2020
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie#readme
synopsis:             Auto generate hie-bios cradles & hie.yaml
description:
    Auto generate a stack or cabal multi component hie.yaml file

category:             Development, Tools, Hie, HLS
abi:                  ef8ed46dbddecdb8f29a64bef8af2f89
exposed:              True
exposed-modules:      Hie.Cabal.Parser Hie.Locate Hie.Yaml
hidden-modules:       Paths_implicit_hie
import-dirs:          /usr/lib/ghc-9.4.8/site-local/implicit-hie-0.1.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/implicit-hie-0.1.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/implicit-hie-0.1.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-implicit-hie
hs-libraries:         HSimplicit-hie-0.1.2.7-5p617Ku40Om7Begu7MEW9W
depends:
    attoparsec-0.14.4-x6mFqXglGqIZ8dJ9fSoCx base-4.17.2.1
    directory-1.3.7.1 filepath-1.4.2.2
    filepattern-0.1.3-IRuCHpopzaJ5nrGcRsloaT text-2.0.2
    transformers-0.5.6.2 yaml-0.11.11.2-k5JnsslwX48CYsOhNsqzT

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie/html/implicit-hie.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-implicit-hie-0.1.2.7-209-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-implicit-hie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 implicit-hie
version:              0.1.2.7
visibility:           public
id:                   implicit-hie-0.1.2.7-7pbNlduNztqGIHladhQoRj
key:                  implicit-hie-0.1.2.7-7pbNlduNztqGIHladhQoRj
license:              BSD-3-Clause
copyright:            2020
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie#readme
synopsis:             Auto generate hie-bios cradles & hie.yaml
description:
    Auto generate a stack or cabal multi component hie.yaml file

category:             Development, Tools, Hie, HLS
abi:                  e01fcd18b84f423e5897042c0c8730b5
exposed:              True
exposed-modules:      Hie.Cabal.Parser Hie.Locate Hie.Yaml
hidden-modules:       Paths_implicit_hie
import-dirs:          /usr/lib/ghc-9.4.8/site-local/implicit-hie-0.1.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/implicit-hie-0.1.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/implicit-hie-0.1.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-implicit-hie
hs-libraries:         HSimplicit-hie-0.1.2.7-7pbNlduNztqGIHladhQoRj
depends:
    attoparsec-0.14.4-5WJushYcFmLGCbqKFNMNd6 base-4.17.2.1
    directory-1.3.7.1 filepath-1.4.2.2
    filepattern-0.1.3-AOY9zWnPRJJGEh0dGQVVey text-2.0.2
    transformers-0.5.6.2 yaml-0.11.11.2-1BX8zrqeWicCfVb3vlAqfh

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie/html/implicit-hie.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
